# badabump

[![CalVer](https://img.shields.io/badge/calver-YY.MINOR.MICRO-22bfda)](https://calver.org)
[![CI Workflow](https://github.com/playpauseandstop/badabump/workflows/ci/badge.svg)](https://github.com/playpauseandstop/badabump/actions?query=workflow%3A%22ci%22)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://pre-commit.com)
[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](https://github.com/commitizen-tools/commitizen#integrating-with-pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Latest Version](https://img.shields.io/pypi/v/badabump.svg)](https://pypi.org/project/badabump/)
[![Python Versions](https://img.shields.io/pypi/pyversions/badabump.svg)](https://pypi.org/project/badabump/)
[![BSD License](https://img.shields.io/pypi/l/badabump.svg)](https://github.com/playpauseandstop/badabump/blob/master/LICENSE)
[![Coverage](https://coveralls.io/repos/playpauseandstop/badabump/badge.svg?branch=master&service=github)](https://coveralls.io/github/playpauseandstop/badabump)

Manage changelog and bump project version number using conventional commits from latest git tag. Support Python, JavaScript projects. Understand CalVer, SemVer version schemas. Designed to run at GitHub Actions.
